summaryrefslogtreecommitdiffstats
path: root/kexi/3rdparty/kexisql3/src/select.c
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/3rdparty/kexisql3/src/select.c')
-rw-r--r--kexi/3rdparty/kexisql3/src/select.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/kexi/3rdparty/kexisql3/src/select.c b/kexi/3rdparty/kexisql3/src/select.c
index 0f465c09..fd8b41a8 100644
--- a/kexi/3rdparty/kexisql3/src/select.c
+++ b/kexi/3rdparty/kexisql3/src/select.c
@@ -2569,7 +2569,7 @@ static void updateAccumulator(Parse *pParse, AggInfo *pAggInfo){
** This routine does NOT free the Select structure passed in. The
** calling function needs to do that.
**
** The pParent, tqparentTab, and *pParentAgg fields are filled in if this
** SELECT is a subquery. This routine may try to combine this SELECT
** with its tqparent to form a single flat query. In so doing, it might
** change the tqparent query from a non-aggregate to an aggregate query.
@@ -2587,7 +2587,7 @@ static void updateAccumulator(Parse *pParse, AggInfo *pAggInfo){
** pParent will be NULL. During the processing of the outer query, this
** routine is called recursively to handle the subquery. For the recursive
** call, pParent will point to the outer query. Because the subquery is
** the second element in a three-way join, the tqparentTab parameter will
** be 1 (the 2nd value of a 0-indexed array.)
*/
int sqlite3Select(
@@ -2596,7 +2596,7 @@ int sqlite3Select(
int eDest, /* How to dispose of the results */
int iParm, /* A parameter used by the eDest disposal method */
Select *pParent, /* Another SELECT for which this is a sub-query */
- int tqparentTab, /* Index in pParent->pSrc of this query */
+ int parentTab, /* Index in pParent->pSrc of this query */
int *pParentAgg, /* True if pParent uses aggregate functions */
char *aff /* If eDest is SRT_Union, the affinity string */
){
@@ -2735,7 +2735,7 @@ int sqlite3Select(
*/
#ifndef SQLITE_OMIT_VIEW
if( pParent && pParentAgg &&
- flattenSubquery(pParse, pParent, tqparentTab, *pParentAgg, isAgg) ){
+ flattenSubquery(pParse, pParent, parentTab, *pParentAgg, isAgg) ){
if( isAgg ) *pParentAgg = 1;
goto select_end;
}
@@ -3105,10 +3105,10 @@ int sqlite3Select(
** the use of the temporary table.
*/
if( pParent ){
- assert( pParent->pSrc->nSrc>tqparentTab );
- assert( pParent->pSrc->a[tqparentTab].pSelect==p );
+ assert( pParent->pSrc->nSrc>parentTab );
+ assert( pParent->pSrc->a[parentTab].pSelect==p );
sqlite3SelectDelete(p);
- pParent->pSrc->a[tqparentTab].pSelect = 0;
+ pParent->pSrc->a[parentTab].pSelect = 0;
}
#endif
@@ -2569,7 +2569,7 @@ static void updateAccumulator(Parse *pParse, AggInfo *pAggInfo){
** calling function needs to do that.
**
-** The pParent, tqparentTab, and *pParentAgg fields are filled in if this
+** The pParent, parentTab, and *pParentAgg fields are filled in if this
** SELECT is a subquery. This routine may try to combine this SELECT
** with its tqparent to form a single flat query. In so doing, it might
@@ -2587,7 +2587,7 @@ static void updateAccumulator(Parse *pParse, AggInfo *pAggInfo){
** routine is called recursively to handle the subquery. For the recursive
** call, pParent will point to the outer query. Because the subquery is
-** the second element in a three-way join, the tqparentTab parameter will
+** the second element in a three-way join, the parentTab parameter will
** be 1 (the 2nd value of a 0-indexed array.)
*/